import Taro, { request } from '@tarojs/taro';
import store from '../store/index';

export type ResponseDataEntity = {
  code: number;
  msg: string;
  data: any;
  [propName: string]: any;
};

type ResponseEntity = {
  data: ResponseDataEntity;
  [propName: string]: any;
};

const createFetch = (basePath: string) => {
  return (entity: request.Param): Promise<ResponseDataEntity> => {
    const token = store.getState().userinfo.token;
    return Taro.request({
      ...entity,
      header: token
        ? {
            token: token,
          }
        : {},
      url: basePath + entity.url,
    }).then(({ data }: ResponseEntity) => {
      if (data.code === 1000) {
        return data;
      }
      Taro.showToast({
        title: data.msg,
        icon: 'none',
      });
      throw data;
    });
  };
};

export default createFetch;
